#include	"unpipc.h"

#include	<stdarg.h>		/* ANSI C header file */
#include	<syslog.h>		/* for syslog() */

static void err_doit(int errnoflag, int level, const char *fmt, va_list ap)
{
	int		errno_save, n;
	char	buf[MAXLINE];

	errno_save = errno;		/* value caller might want printed */
	vsnprintf(buf, sizeof(buf), fmt, ap);	/* this is safe */
//	vsprintf(buf, fmt, ap);					/* this is not safe */
	n = strlen(buf);
	if (errnoflag)
		snprintf(buf+n, sizeof(buf)-n, ": %s", strerror(errno_save));
	strcat(buf, "\n");

	fflush(stdout);		/* in case stdout and stderr are the same */
	fputs(buf, stderr);
	fflush(stderr);

	return;
}


void err_quit(const char *fmt, ...)
{
	va_list		ap;

	va_start(ap, fmt);
	err_doit(0, LOG_ERR, fmt, ap);
	va_end(ap);
	exit(1);
}


void err_sys(const char *fmt, ...)
{
	va_list		ap;

	va_start(ap, fmt);
	err_doit(1, LOG_ERR, fmt, ap);
	va_end(ap);
	exit(1);
}


void Stat(const char *pathname, struct stat *ptr)
{
	if (stat(pathname, ptr) == -1)
		err_sys("stat error");
}

key_t Ftok(const char *pathname, int id)
{
	key_t	key;

	if ( (key = ftok(pathname, id)) == -1)
		err_sys("ftok error for pathname \"%s\" and id %d", pathname, id);
	return(key);
}


int main(int argc, char **argv)
{
	struct stat	stat;

	if (argc != 2)
		err_quit("usage: ftok <pathname>");

	Stat(argv[1], &stat);
	printf("st_dev: %lx, st_ino: %lx, key: %x\n",
		   (u_long) stat.st_dev, (u_long) stat.st_ino,
		   Ftok(argv[1], 0x57));

	exit(0);
}
